from collective.deletepermission.tests.base import duplicate_with_dexterity
from collective.deletepermission.tests.base import FunctionalTestCase
from ftw.builder import Builder
from ftw.builder import create
from OFS.CopySupport import CopyError


@duplicate_with_dexterity
class TestCorrectPermissions(FunctionalTestCase):

    def setUp(self):
        self.user_a = create(Builder('user').with_userid('usera'))
        self.user_b = create(Builder('user').with_userid('userb'))

        self.folder = create(self.folder_builder().titled(u'rootfolder'))
        self.set_local_roles(self.folder, self.user_a, 'Contributor')
        self.set_local_roles(self.folder, self.user_b, 'Contributor')

        with self.user(self.user_a):
            self.folder_a = create(self.folder_builder().within(self.folder)
                                   .titled(u'folder-a'))
            self.doc_a = create(self.folder_builder().within(self.folder_a)
                                .titled(u'doc-a'))

        with self.user(self.user_b):
            self.doc_b = create(self.folder_builder().within(self.folder_a)
                                .titled(u'doc-b'))

    def test_usera_cut_folder(self):
        """usera should be able to cut his own folder
        becauase he is its Owner"""

        with self.user(self.user_a):
            self.folder.manage_cutObjects(['folder-a'])

    def test_userb_cut_folder(self):
        """userb should NOT be able to cut usera's folder, because he is
        not its Owner"""

        with self.user(self.user_b):
            self.assertRaises(CopyError,
                              self.folder.manage_cutObjects,
                              ['folder-a'])

    def test_usera_cut_doc_a(self):
        """usera should be able to cut doc-a, because he is its Owner"""

        with self.user(self.user_a):
            self.folder_a.manage_cutObjects(['doc-a'])

    def test_usera_cut_doc_b(self):
        """usera should be able to cut doc-b, because ???????????????????"""
        # XXX why?

        with self.user(self.user_a):
            self.folder_a.manage_cutObjects(['doc-b'])

    def test_userb_cut_doc_a(self):
        """userb should NOT be able to cut coc-a, because his not Owner"""
        # XXX should this be raised upon paste??

        with self.user(self.user_b):
            self.assertRaises(CopyError,
                              self.folder_a.manage_cutObjects,
                              'doc-a')

    def test_userb_cut_doc_b(self):
        """userb should be able to cut his own document"""

        with self.user(self.user_b):
            self.folder_a.manage_cutObjects(['doc-b'])

    def test_cut_multiple(self):
        """Cutting objects INCLUDING an object which cannot be cut should not
        raise, so that the OTHER object is cut (not the transaction not
        cancelled because of the exception)
        """

        with self.user(self.user_a):
            self.folder_a.manage_cutObjects(['doc-a', 'doc-b'])

    def test_cut_empty(self):
        """Cutting "None" should throw a ValueError."""

        with self.user(self.user_a):
            self.assertRaises(
                ValueError, self.folder_a.manage_cutObjects, None)



from AccessControl import Unauthorized
from collective.deletepermission.tests.base import duplicate_with_dexterity
from collective.deletepermission.tests.base import FunctionalTestCase
from ftw.builder import create
from plone.app.testing import login
from plone.app.testing import setRoles
from plone.app.testing import TEST_USER_ID
from plone.app.testing import TEST_USER_NAME


@duplicate_with_dexterity
class TestCopy(FunctionalTestCase):

    def setUp(self):
        self.portal = self.layer['portal']
        setRoles(self.portal, TEST_USER_ID, ['Contributor'])
        login(self.portal, TEST_USER_NAME)

    def test_copy_works_without_beeing_able_to_delete(self):
        folder = create(self.folder_builder())
        self.revoke_permission('Delete portal content', on=folder)
        folder.object_copy()
        if self.is_dexterity_test():
            self.assertEquals([u'dxfolder copied.'], self.get_status_messages())
        else:
            self.assertEquals([u'folder copied.'], self.get_status_messages())

    def test_copy_denied_without_copy_or_move_permission(self):
        folder = create(self.folder_builder())
        self.revoke_permission('Copy or Move', on=folder)
        with self.assertRaises(Unauthorized):
            folder.object_copy()



from ftw.builder.dexterity import DexterityBuilder
from ftw.builder import builder_registry


class DXFolderBuilder(DexterityBuilder):
    portal_type = 'dxfolder'

builder_registry.register('dxfolder', DXFolderBuilder)



from plone.dexterity.content import Container
from collective.deletepermission.del_object import protect_del_objects


def manage_delObjects(self, ids=None, REQUEST=None):
    """We need to enforce security."""
    protect_del_objects(self, ids)
    return super(Container, self).manage_delObjects(ids, REQUEST=REQUEST)



from ftw.builder.testing import BUILDER_LAYER
from ftw.builder.testing import functional_session_factory
from ftw.builder.testing import set_builder_session_factory
from plone.app.testing import applyProfile
from plone.app.testing import FunctionalTesting
from plone.app.testing import PLONE_FIXTURE
from plone.app.testing import PloneSandboxLayer
from plone.app.testing import setRoles, TEST_USER_ID, TEST_USER_NAME, login
import collective.deletepermission.tests.builders


class CollectiveDeletepermissionLayer(PloneSandboxLayer):

    defaultBases = (PLONE_FIXTURE, BUILDER_LAYER)

    def setUpZope(self, app, configurationContext):
        import plone.app.dexterity
        import collective.deletepermission
        self.loadZCML(package=plone.app.dexterity)
        self.loadZCML(package=collective.deletepermission)
        self.loadZCML(package=collective.deletepermission.tests,
                      name='test.zcml')

    def setUpPloneSite(self, portal):
        applyProfile(portal, 'collective.deletepermission:default')
        applyProfile(portal, 'collective.deletepermission.tests:dxtests')
        setRoles(portal, TEST_USER_ID, ['Manager', 'Contributor'])
        login(portal, TEST_USER_NAME)


COLLECTIVE_DELETEPERMISSION_FIXTURE = CollectiveDeletepermissionLayer()
COLLECTIVE_DELETEPERMISSION_FUNCTIONAL_TESTING = FunctionalTesting(
    bases=(COLLECTIVE_DELETEPERMISSION_FIXTURE,
           set_builder_session_factory(functional_session_factory)),
    name="CollectiveDeletepermission:Functional")



from AccessControl import Unauthorized
from collective.deletepermission.tests.base import duplicate_with_dexterity
from collective.deletepermission.tests.base import FunctionalTestCase
from ftw.builder import Builder
from ftw.builder import create


@duplicate_with_dexterity
class TestCorrectPermissions(FunctionalTestCase):

    def setUp(self):
        self.user_a = create(Builder('user').with_userid('usera'))
        self.user_b = create(Builder('user').with_userid('userb'))

        self.folder = create(self.folder_builder().titled(u'rootfolder'))
        self.set_local_roles(self.folder, self.user_a, 'Contributor')
        self.set_local_roles(self.folder, self.user_b, 'Contributor')

        with self.user(self.user_a):
            self.folder_a = create(self.folder_builder().within(self.folder)
                                   .titled(u'folder-a'))
            self.doc_a = create(self.folder_builder().within(self.folder_a)
                                .titled(u'doc-a'))

        with self.user(self.user_b):
            self.doc_b = create(self.folder_builder().within(self.folder_a)
                                .titled(u'doc-b'))

    def test_usera_remove_folder(self):
        """Test if usera can remove his folder"""
        with self.user(self.user_a):
            self.folder.manage_delObjects('folder-a')

    def test_userb_remove_folder(self):
        """Test if userb can't delete usera's folder"""
        with self.user(self.user_b):
            self.assertRaises(Unauthorized,
                              self.folder.manage_delObjects,
                              'folder-a')

    def test_usera_remove_doc_a(self):
        """Test if usera can remove his doc"""
        with self.user(self.user_a):
            self.folder_a.manage_delObjects('doc-a')

    def test_usera_remove_doc_b(self):
        """Test if usera can remove userb's folder"""
        with self.user(self.user_a):
            self.folder_a.manage_delObjects('doc-b')

    def test_userb_remove_doc_a(self):
        """Test if userb can remove usera's folder"""
        with self.user(self.user_b):
            self.assertRaises(Unauthorized,
                              self.folder_a.manage_delObjects,
                              'doc-a')

    def test_userb_remove_doc_b(self):
        """Test if userb can remove his doc"""
        with self.user(self.user_b):
            self.folder_a.manage_delObjects('doc-b')

    def test_remove_multiple(self):
        """Test if we still are able to remove multiple objects at once."""
        with self.user(self.user_a):
            self.folder_a.manage_delObjects(['doc-a', 'doc-b'])
            self.assertEqual(self.folder_a.objectIds(), [])

    def test_remove_empty(self):
        """Check that we don't throw errors if we get a id that is none'"""
        with self.user(self.user_a):
            self.folder_a.manage_delObjects(None)



from AccessControl import getSecurityManager
from collective.deletepermission.tests.base import duplicate_with_dexterity
from collective.deletepermission.tests.base import FunctionalTestCase
from ftw.builder import Builder
from ftw.builder import create
from zExceptions import Unauthorized


@duplicate_with_dexterity
class TestDeleeting(FunctionalTestCase):

    def setUp(self):
        self.contributor = create(Builder('user').with_roles('Contributor'))
        self.parent = create(self.folder_builder())
        self.child = create(self.folder_builder().within(self.parent))

    def test_delete_possible_with_both_permissions(self):
        self.parent.manage_permission('Delete objects',
                                 roles=['Contributor'], acquire=False)
        self.child.manage_permission('Delete portal content',
                                roles=['Contributor'], acquire=False)

        with self.user(self.contributor):
            self.assertIn(self.child.getId(), self.parent.objectIds())
            self.parent.manage_delObjects([self.child.getId()])
            self.assertNotIn(self.child.getId(), self.parent.objectIds())

    def test_delete_unauthorized_when_no_permission_on_child(self):
        self.parent.manage_permission('Delete objects',
                                      roles=['Contributor'], acquire=False)
        self.child.manage_permission('Delete portal content',
                                     roles=[], acquire=False)

        with self.user(self.contributor):
            with self.assertRaises(Unauthorized):
                self.parent.manage_delObjects([self.child.getId()])

    def test_delete_unauthorized_when_no_permission_on_parent(self):
        with self.user(self.contributor):
            checkPermission = getSecurityManager().checkPermission
            self.assertTrue(checkPermission('Delete objects', self.parent))

            self.parent.manage_permission('Delete objects',
                                          roles=[], acquire=False)
            self.child.manage_permission('Delete portal content',
                                         roles=['Contributor'], acquire=False)

            self.assertFalse(checkPermission('Delete objects', self.parent))
            with self.assertRaises(Unauthorized):
                self.parent.manage_delObjects([self.child.getId()])



from AccessControl import Unauthorized
from collective.deletepermission.tests.base import duplicate_with_dexterity
from collective.deletepermission.tests.base import FunctionalTestCase
from ftw.builder import Builder
from ftw.builder import create
from ftw.testbrowser import browsing


@duplicate_with_dexterity
class TestOnlyFiles(FunctionalTestCase):

    def setUp(self):
        self.user_a = create(Builder('user').with_userid('usera'))

        self.folder = create(self.folder_builder().titled(u'rootfolder'))
        self.set_local_roles(self.folder, self.user_a, 'Contributor')

        self.subfolder = create(self.folder_builder().titled(u'subfolder')
                                .within(self.folder))

        with self.user(self.user_a):
            self.firstleveldoc = create(self.folder_builder()
                                        .titled(u'doc-firstleveldoc')
                                        .within(self.folder))
            self.secondleveldoc = create(self.folder_builder()
                                         .titled(u'doc-secondleveldoc')
                                         .within(self.subfolder))

    @browsing
    def test_delete_secondlevel(self, browser):
        """Test if we are able to delete the file in the subfolder"""
        browser.login(self.user_a).open(self.secondleveldoc, view='delete_confirmation')
        browser.find('Delete').click()

    @browsing
    def test_delete_firstlevel(self, browser):
        """Test if we are able to delete the file in the rootfolder"""
        browser.login(self.user_a).open(self.firstleveldoc, view='delete_confirmation')
        browser.find('Delete').click()

    @browsing
    def test_delete_subfolder(self, browser):
        """Test if we can delete the subfolder. This should not be the case."""
        browser.login(self.user_a).open(self.subfolder, view='delete_confirmation')
        with self.assertRaises(Unauthorized):
            browser.find('Delete').click()



from collective.deletepermission.tests.base import duplicate_with_dexterity
from AccessControl import Unauthorized
from collective.deletepermission.tests.base import FunctionalTestCase
from ftw.builder import Builder
from ftw.builder import create
from ftw.testbrowser import browsing
from ftw.testbrowser.pages import folder_contents
from ftw.testbrowser.pages import plone
from ftw.testbrowser.pages import statusmessages


@duplicate_with_dexterity
class TestCorrectPermissions(FunctionalTestCase):

    def setUp(self):
        self.user_a = create(Builder('user').with_userid('usera'))
        self.user_b = create(Builder('user').with_userid('userb'))

        self.folder = create(self.folder_builder().titled(u'rootfolder'))
        self.set_local_roles(self.folder, self.user_a, 'Contributor')
        self.set_local_roles(self.folder, self.user_b, 'Contributor')

        with self.user(self.user_a):
            self.folder_a = create(self.folder_builder().within(self.folder)
                                   .titled(u'folder-a'))
            self.doc_a = create(self.folder_builder().within(self.folder_a)
                                .titled(u'doc-a'))

        with self.user(self.user_b):
            self.doc_b = create(self.folder_builder().within(self.folder_a)
                                .titled(u'doc-b'))

    @browsing
    def test_userb_delete_docb(self, browser):
        """
        Check if User B is able to delete his own document.
        """
        browser.login(self.user_b).open(self.doc_b, view='delete_confirmation')
        browser.find('Delete').click()

    @browsing
    def test_userb_cut_docb(self, browser):
        """
        Check if User B is able to cut his own document.
        """
        browser.login(self.user_b).open(self.doc_b)
        browser.find('Cut').click()

    @browsing
    def test_userb_rename_docb(self, browser):
        """
        Check if User B is able to rename his own document.
        """
        browser.login(self.user_b).open(self.doc_b)
        browser.find('Rename').click()
        browser.fill({'new_ids:list': 'doc-b-renamed'}
                     ).find('Rename All').click()
        statusmessages.assert_no_error_messages()
        self.assertEquals(self.folder_a.absolute_url() + '/doc-b-renamed',
                          browser.url)

    @browsing
    def test_usera_remove_folder(self, browser):
        """
        Test if User A is able to delete his folder
        """
        browser.login(self.user_a).open(self.folder_a,
                                        view='delete_confirmation')
        browser.find('Delete').click()

    @browsing
    def test_usera_cut_folder(self, browser):
        """
        Test if User A is able to cut his folder
        """
        browser.login(self.user_a).open(self.folder_a)
        browser.find('Cut').click()

    @browsing
    def test_usera_rename_folder(self, browser):
        """
        Test if User A is able to rename his folder
        """
        browser.login(self.user_a).open(self.folder_a)
        browser.find('Rename').click()
        browser.fill({'new_ids:list': 'folder-a-renamed'}
                     ).find('Rename All').click()
        statusmessages.assert_no_error_messages()
        self.assertEquals(self.folder.absolute_url() + '/folder-a-renamed',
                          browser.url)

    @browsing
    def test_userb_remove_folder(self, browser):
        """
        Check if User B can delete User A's folder. Should not be possible.
        """
        browser.login(self.user_b).open(self.folder_a,
                                        view='delete_confirmation')
        with self.assertRaises(Unauthorized):
            browser.find("Delete").click()

    @browsing
    def test_userb_cut_folder(self, browser):
        """
        Check if User B can't cut User A's folder.
        """
        browser.login(self.user_b).open(self.folder_a)
        self.assertNotIn('Cut', self.get_actions())
        browser.open(self.folder_a, view='object_cut')
        self.assertEquals(['folder-a is not moveable.'],
                          statusmessages.error_messages())

    @browsing
    def test_userb_rename_folder(self, browser):
        """
        Check if User B can't rename User A's folder.
        """
        browser.login(self.user_b).open(self.folder_a)
        self.assertNotIn('Rename', self.get_actions())
        with self.assertRaises(Unauthorized):
            browser.open(self.folder_a, view='object_rename')

    @browsing
    def test_usera_remove_doc_a(self, browser):
        """
        Test if User A is able to delete his own Document.
        """
        browser.login(self.user_a).open(self.doc_a, view='delete_confirmation')
        browser.find("Delete").click()

    @browsing
    def test_usera_cut_doc_a(self, browser):
        """
        Test if User A is able to cut his own Document.
        """
        browser.login(self.user_a).open(self.doc_a)
        browser.find('Cut').click()

    @browsing
    def test_usera_rename_doc_a(self, browser):
        """
        Test if User A is able to rename his own Document.
        """
        browser.login(self.user_a).open(self.doc_a)
        browser.find('Rename').click()
        browser.fill({'new_ids:list': 'doc-a-renamed',
                      }).find('Rename All').click()
        statusmessages.assert_no_error_messages()
        self.assertEquals(self.folder_a.absolute_url() + '/doc-a-renamed',
                          browser.url)

    @browsing
    def test_usera_remove_doc_b(self, browser):
        """
        Test if User A is able to delete the Document of User B
        """
        browser.login(self.user_a).open(self.doc_b, view='delete_confirmation')
        browser.find('Delete').click()

    @browsing
    def test_usera_cut_doc_b(self, browser):
        """
        Test if User A is able to cut the Document of User B
        """
        browser.login(self.user_a).open(self.doc_b)
        browser.find('Cut').click()

    @browsing
    def test_usera_rename_doc_b(self, browser):
        """
        Test if User A is able to rename the Document of User B
        """
        browser.login(self.user_a).open(self.doc_b)
        browser.find('Rename').click()
        browser.fill({'new_ids:list': 'doc-b-renamed',
                      }).find('Rename All').click()
        statusmessages.assert_no_error_messages()
        self.assertEquals(self.folder_a.absolute_url() + '/doc-b-renamed',
                          browser.url)

    @browsing
    def test_userb_remove_doc_a(self, browser):
        """
        Check if User B can remove User A's Document. Should not be possible.
        """
        browser.login(self.user_b).open(self.doc_a, view='delete_confirmation')
        with self.assertRaises(Unauthorized):
            browser.find('Delete').click()

    @browsing
    def test_userb_cut_doc_a(self, browser):
        """
        Check if User B can't remove User A's Document.
        """
        browser.login(self.user_b).open(self.doc_a)
        self.assertNotIn('Cut', self.get_actions())
        browser.open(self.doc_a, view='object_cut')
        self.assertEquals(['doc-a is not moveable.'],
                          statusmessages.error_messages())

    @browsing
    def test_userb_rename_doc_a(self, browser):
        """
        Check if User B can't rename User A's Document.
        """
        browser.login(self.user_b).open(self.doc_a)
        self.assertNotIn('Rename', self.get_actions())
        with self.assertRaises(Unauthorized):
            browser.open(self.folder_a, view='object_rename')

    @browsing
    def test_usera_remove_docs_folder_contents(self, browser):
        """Check if we are able to remove files over folder_contents."""
        browser.login(self.user_a).open(self.folder_a, view='folder_contents')
        folder_contents.select(self.doc_a, self.doc_b)
        folder_contents.form().find('Delete').click()
        self.assertEqual(['Item(s) deleted.'], statusmessages.info_messages())

    @browsing
    def test_usera_cuts_docs_folder_contents(self, browser):
        """Check if we are able to cut docs over folder_contents."""
        browser.login(self.user_a).open(self.folder_a, view='folder_contents')
        folder_contents.select(self.doc_a, self.doc_b)
        folder_contents.form().find('Cut').click()
        self.assertEqual({'info': ['2 item(s) cut.'],
                          'warning': [],
                          'error': []}, statusmessages.messages())

    @browsing
    def test_usera_renames_docs_folder_contents(self, browser):
        """Check if we are able to rename docs over folder_contents."""
        browser.login(self.user_a).open(self.folder_a, view='folder_contents')
        folder_contents.select(self.doc_a, self.doc_b)
        folder_contents.form().find('Rename').click()
        self.assertEqual('folder_rename_form', plone.view())
        self.assertEqual('doc-a', browser.css('#doc-a_id').first.value)
        self.assertEqual('doc-b', browser.css('#doc-b_id').first.value)

    @browsing
    def test_userb_remove_docs_folder_contents(self, browser):
        """Check if the permission also works when we delete over
        folder_contents.
        """
        browser.login(self.user_b).open(self.folder_a, view='folder_contents')
        folder_contents.select(self.doc_a, self.doc_b)
        folder_contents.form().find('Delete').click()
        self.assertEqual(
            {'info': ['/plone/rootfolder/folder-a/doc-a'
                      ' could not be deleted.'],
             'warning': [],
             'error': []}, statusmessages.messages())

    @browsing
    def test_userb_cuts_docs_folder_contents(self, browser):
        """Check if the permission also works when we cut over
        folder_contents.
        """
        browser.login(self.user_b).open(self.folder_a, view='folder_contents')
        folder_contents.select(self.doc_a, self.doc_b)
        folder_contents.form().find('Cut').click()
        self.assertEqual({'info': [],
                          'warning': [],
                          'error': ['One or more items not moveable.']},
                         statusmessages.messages())

    @browsing
    def test_userb_renames_docs_folder_contents(self, browser):
        """Check if the permission also works when we rename over
        folder_contents.
        """
        browser.login(self.user_b).open(self.folder_a, view='folder_contents')
        folder_contents.select(self.doc_a, self.doc_b)
        folder_contents.form().find('Rename').click()
        self.assertEqual('folder_rename_form', plone.view())
        self.assertEqual(
            ['You are not allowed to modify the id of this item.',
             'You are not allowed to modify the title of this item.'],
            browser.css('#content fieldset .error span').text)
        self.assertFalse(browser.css('#doc-a_id'))
        self.assertEqual('doc-b', browser.css('#doc-b_id').first.value)



from AccessControl.SecurityManagement import getSecurityManager
from AccessControl.SecurityManagement import setSecurityManager
from collective.deletepermission import testing
from contextlib import contextmanager
from ftw.builder import Builder
from ftw.testbrowser import browser
from plone.app.testing import login
from Products.statusmessages.interfaces import IStatusMessage
from unittest2 import TestCase
import sys
import transaction


class FunctionalTestCase(TestCase):

    layer = testing.COLLECTIVE_DELETEPERMISSION_FUNCTIONAL_TESTING
    folder_name = 'Folder'

    def revoke_permission(self, permission, on):
        on.manage_permission(permission, roles=[], acquire=False)

    def set_local_roles(self, context, user, *roles):
        if hasattr(user, 'getUserName'):
            user = user.getUserName()

        context.manage_setLocalRoles(user, tuple(roles))
        context.reindexObjectSecurity()
        transaction.commit()

    def get_status_messages(self):
        request = self.layer['request']
        messages = [msg.message for msg in IStatusMessage(request).show()]
        return messages

    def get_actions(self):
        return browser.css('#plone-contentmenu-actions .actionMenuContent a').text

    @contextmanager
    def user(self, username):
        if hasattr(username, 'getUserName'):
            username = username.getUserName()

        sm = getSecurityManager()
        login(self.layer['portal'], username)
        try:
            yield
        finally:
            setSecurityManager(sm)

    def folder_builder(self):
        return Builder('folder')

    def is_dexterity_test(self):
        return False


def duplicate_with_dexterity(klass):
    """Decorator for duplicating a test suite to be ran against dexterity contents.
    """
    class DexterityTestSuite(klass):
        folder_name = 'dxfolder'

        def folder_builder(self):
            return Builder('dxfolder')

        def is_dexterity_test(self):
            return True

    DexterityTestSuite.__name__ = klass.__name__ + 'Dexterity'
    DexterityTestSuite.__module__ = klass.__module__
    sys._getframe(1).f_locals[DexterityTestSuite.__name__] = DexterityTestSuite
    return klass




def upgrade(setup_context):
    setup_context.runImportStepFromProfile(
        'profile-collective.deletepermission.upgrades:1001',
        'actions',
        run_dependencies=False,
        purge_old=False)



from collective.deletepermission.tests.base import duplicate_with_dexterity
from collective.deletepermission.tests.base import FunctionalTestCase
from ftw.builder import Builder
from ftw.builder import create
from ftw.testbrowser import browsing
import transaction


@duplicate_with_dexterity
class TestDeleteAction(FunctionalTestCase):

    def setUp(self):
        self.hugo = create(Builder('user').named('Hugo', 'Boss')
                           .with_roles('Member', 'Contributor'))
        self.john = create(Builder('user').named('John', 'Doe')
                           .with_roles('Member', 'Contributor'))
        with self.user(self.hugo):
            self.container = create(self.folder_builder())
        with self.user(self.john):
            self.content = create(self.folder_builder().within(self.container))

    @browsing
    def test_user_can_delete_own_contents(self, browser):
        browser.login(self.john).visit(self.content)
        self.assertIn('Delete', self.get_actions(),
                      'A user should be able to delete his own content.')

    @browsing
    def test_user_can_not_delete_without_delete_objects_on_parent(self,
                                                                  browser):
        self.revoke_permission('Delete objects', on=self.container)
        transaction.commit()
        browser.login(self.john).visit(self.content)
        self.assertNotIn('Delete', self.get_actions(),
                         'A user should not be able to delete content'
                         ' without "Delete objects" on the parent.')


@duplicate_with_dexterity
class TestCutAction(FunctionalTestCase):

    def setUp(self):
        self.hugo = create(Builder('user').named('Hugo', 'Boss')
                           .with_roles('Member', 'Contributor'))
        self.john = create(Builder('user').named('John', 'Doe')
                           .with_roles('Member', 'Contributor'))
        with self.user(self.hugo):
            self.container = create(self.folder_builder())
        with self.user(self.john):
            self.content = create(self.folder_builder().within(self.container))

    @browsing
    def test_user_can_cut_own_contents(self, browser):
        browser.login(self.john).visit(self.content)
        self.assertIn('Cut', self.get_actions(),
                      'A user should be able to cut his own content.')

    @browsing
    def test_user_can_not_cut_without_delete_objects_on_parent(self, browser):
        self.revoke_permission('Delete objects', on=self.container)
        transaction.commit()
        browser.login(self.john).visit(self.content)
        self.assertNotIn('Cut', self.get_actions(),
                         'A user should not be able to cut content'
                         ' without "Delete objects" on the parent.')



from AccessControl import getSecurityManager
from AccessControl.PermissionRole import PermissionRole
from AccessControl.Permissions import copy_or_move


def cb_userHasCopyOrMovePermission(self):
    has_copy_or_move = getSecurityManager().checkPermission(copy_or_move, self)
    has_del = getSecurityManager().checkPermission(
        "Delete portal content", self)
    # import ipdb; ipdb.set_trace()
    if has_copy_or_move and has_del:
        return 1


# Patch manage_cutObjects security.
# By default AT's BaseFolderMixin sets the permission of manage_cutObjects
# to ModifyPortalContent
# We have to change this afterwards.
# Set manage_cutObjects__roles__, which stores the definition generated by
# AccessControl.class_init or App.class_init.
def apply_delete_objects_permission_role(klass, name, replacement):
    setattr(klass, name, PermissionRole('Delete objects', None))


def dummy_replacement():
    pass



from setuptools import setup, find_packages
import os

version = '1.3.0'

tests_require = [
    'AccessControl',
    'Products.CMFCore',
    'Products.GenericSetup',
    'Products.statusmessages',
    'Zope2',
    'ftw.builder',
    'ftw.testbrowser',
    'plone.app.dexterity',
    'plone.app.portlets',
    'plone.app.testing',
    'plone.autoform',
    'transaction',
    'unittest2',
    'zExceptions',
    'zope.interface',
    ]


extras_require = {
    'tests': tests_require,
    }


long_description = (
    open('README.rst').read()
    + '\n' +
    open(os.path.join('docs', 'HISTORY.txt')).read()
    + '\n')

setup(name='collective.deletepermission',
      version=version,
      description="Implements a new permission 'Delete portal content'",
      long_description=long_description.decode('utf-8'),

      # Get more strings from
      # http://pypi.python.org/pypi?%3Aaction=list_classifiers
      classifiers=[
        "Programming Language :: Python",
        'Framework :: Plone',
        'Framework :: Plone :: 4.1',
        'Framework :: Plone :: 4.2',
        'Framework :: Plone :: 4.3',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Libraries :: Python Modules',
        ],

      keywords='collective deletepermission 4teamwork ftw plone',
      author='4teamwork AG',
      author_email='mailto:info@4teamwork.ch',
      url='https://github.com/4teamwork/collective.deletepermission',
      license='GPL2',

      packages=find_packages(exclude=['ez_setup']),
      namespace_packages=['collective'],
      include_package_data=True,
      zip_safe=False,

      install_requires=[
        'AccessControl',
        'Acquisition',
        'Products.Archetypes',
        'Products.CMFCore',
        'Products.CMFPlone',
        'Products.GenericSetup',
        'Products.PythonScripts',
        'ZODB3',
        'Zope2',
        'collective.monkeypatcher',
        'setuptools',
        'zope.container',
        'zope.event',
        'zope.lifecycleevent',
        ],

      tests_require=tests_require,
      extras_require=extras_require,

      entry_points="""
      # -*- Entry points: -*-
      [z3c.autoinclude.plugin]
      target = plone
      """,
      )



## Python Script "object_rename"
##bind container=container
##bind context=context
##bind namespace=
##bind script=script
##bind subpath=traverse_subpath
##parameters=
##title=Show the rename form for an object
##

from Products.CMFPlone.utils import safe_unicode

from Products.CMFCore.utils import getToolByName
from Products.CMFPlone import PloneMessageFactory as _
from AccessControl import Unauthorized
from Products.PythonScripts.standard import url_quote_plus

REQUEST = context.REQUEST
title = safe_unicode(context.title_or_id())

mtool = getToolByName(context, 'portal_membership')
if not mtool.checkPermission('Copy or Move', context) or \
    not mtool.checkPermission('Delete portal content', context):
    raise Unauthorized, _(u'Permission denied to rename ${title}.',
                          mapping={u'title': title})

pathName = url_quote_plus('paths:list')
safePath = '/'.join(context.getPhysicalPath())
orig_template = REQUEST['HTTP_REFERER'].split('?')[0]
url = '%s/folder_rename_form?orig_template=%s&%s=%s' % (context.absolute_url(),
                                                        orig_template,
                                                        pathName,
                                                        safePath)

REQUEST.RESPONSE.redirect(url)



from collective.deletepermission.tests.base import duplicate_with_dexterity
from collective.deletepermission.tests.base import FunctionalTestCase
from ftw.builder import Builder
from ftw.builder import create
from ftw.testbrowser import browsing
from ftw.testbrowser.pages import factoriesmenu
from ftw.testbrowser.pages import plone
from ftw.testbrowser.pages import statusmessages
import transaction


@duplicate_with_dexterity
class TestFactoryPatch(FunctionalTestCase):

    @browsing
    def test_object_addable_without_delete_permission(self, browser):
        user = create(Builder('user').with_roles('Contributor'))
        self.revoke_permission('Delete portal content', on=self.layer['portal'])
        transaction.commit()

        browser.login(user).open()
        factoriesmenu.add(self.folder_name)
        browser.fill({'Title': 'Foo'}).save()
        statusmessages.assert_no_error_messages()
        self.assertEquals('folder_listing', plone.view())
